// Created with Squiffy 5.1.3
// https://github.com/textadventures/squiffy

(function(){
/* jshint quotmark: single */
/* jshint evil: true */

var squiffy = {};

(function () {
    'use strict';

    squiffy.story = {};

    var initLinkHandler = function () {
        var handleLink = function (link) {
            if (link.hasClass('disabled')) return;
            var passage = link.data('passage');
            var section = link.data('section');
            var rotateAttr = link.attr('data-rotate');
            var sequenceAttr = link.attr('data-sequence');
            if (passage) {
                disableLink(link);
                squiffy.set('_turncount', squiffy.get('_turncount') + 1);
                passage = processLink(passage);
                if (passage) {
                    currentSection.append('<hr/>');
                    squiffy.story.passage(passage);
                }
                var turnPassage = '@' + squiffy.get('_turncount');
                if (turnPassage in squiffy.story.section.passages) {
                    squiffy.story.passage(turnPassage);
                }
                if ('@last' in squiffy.story.section.passages && squiffy.get('_turncount')>= squiffy.story.section.passageCount) {
                    squiffy.story.passage('@last');
                }
            }
            else if (section) {
                currentSection.append('<hr/>');
                disableLink(link);
                section = processLink(section);
                squiffy.story.go(section);
            }
            else if (rotateAttr || sequenceAttr) {
                var result = rotate(rotateAttr || sequenceAttr, rotateAttr ? link.text() : '');
                link.html(result[0].replace(/&quot;/g, '"').replace(/&#39;/g, '\''));
                var dataAttribute = rotateAttr ? 'data-rotate' : 'data-sequence';
                link.attr(dataAttribute, result[1]);
                if (!result[1]) {
                    disableLink(link);
                }
                if (link.attr('data-attribute')) {
                    squiffy.set(link.attr('data-attribute'), result[0]);
                }
                squiffy.story.save();
            }
        };

        squiffy.ui.output.on('click', 'a.squiffy-link', function () {
            handleLink(jQuery(this));
        });

        squiffy.ui.output.on('keypress', 'a.squiffy-link', function (e) {
            if (e.which !== 13) return;
            handleLink(jQuery(this));
        });

        squiffy.ui.output.on('mousedown', 'a.squiffy-link', function (event) {
            event.preventDefault();
        });
    };

    var disableLink = function (link) {
        link.addClass('disabled');
        link.attr('tabindex', -1);
    }
    
    squiffy.story.begin = function () {
        if (!squiffy.story.load()) {
            squiffy.story.go(squiffy.story.start);
        }
    };

    var processLink = function(link) {
		link = String(link);
        var sections = link.split(',');
        var first = true;
        var target = null;
        sections.forEach(function (section) {
            section = section.trim();
            if (startsWith(section, '@replace ')) {
                replaceLabel(section.substring(9));
            }
            else {
                if (first) {
                    target = section;
                }
                else {
                    setAttribute(section);
                }
            }
            first = false;
        });
        return target;
    };

    var setAttribute = function(expr) {
        var lhs, rhs, op, value;
        var setRegex = /^([\w]*)\s*=\s*(.*)$/;
        var setMatch = setRegex.exec(expr);
        if (setMatch) {
            lhs = setMatch[1];
            rhs = setMatch[2];
            if (isNaN(rhs)) {
				if(startsWith(rhs,"@")) rhs=squiffy.get(rhs.substring(1));
                squiffy.set(lhs, rhs);
            }
            else {
                squiffy.set(lhs, parseFloat(rhs));
            }
        }
        else {
			var incDecRegex = /^([\w]*)\s*([\+\-\*\/])=\s*(.*)$/;
            var incDecMatch = incDecRegex.exec(expr);
            if (incDecMatch) {
                lhs = incDecMatch[1];
                op = incDecMatch[2];
				rhs = incDecMatch[3];
				if(startsWith(rhs,"@")) rhs=squiffy.get(rhs.substring(1));
				rhs = parseFloat(rhs);
                value = squiffy.get(lhs);
                if (value === null) value = 0;
                if (op == '+') {
                    value += rhs;
                }
                if (op == '-') {
                    value -= rhs;
                }
				if (op == '*') {
					value *= rhs;
				}
				if (op == '/') {
					value /= rhs;
				}
                squiffy.set(lhs, value);
            }
            else {
                value = true;
                if (startsWith(expr, 'not ')) {
                    expr = expr.substring(4);
                    value = false;
                }
                squiffy.set(expr, value);
            }
        }
    };

    var replaceLabel = function(expr) {
        var regex = /^([\w]*)\s*=\s*(.*)$/;
        var match = regex.exec(expr);
        if (!match) return;
        var label = match[1];
        var text = match[2];
        if (text in squiffy.story.section.passages) {
            text = squiffy.story.section.passages[text].text;
        }
        else if (text in squiffy.story.sections) {
            text = squiffy.story.sections[text].text;
        }
        var stripParags = /^<p>(.*)<\/p>$/;
        var stripParagsMatch = stripParags.exec(text);
        if (stripParagsMatch) {
            text = stripParagsMatch[1];
        }
        var $labels = squiffy.ui.output.find('.squiffy-label-' + label);
        $labels.fadeOut(1000, function() {
            $labels.html(squiffy.ui.processText(text));
            $labels.fadeIn(1000, function() {
                squiffy.story.save();
            });
        });
    };

    squiffy.story.go = function(section) {
        squiffy.set('_transition', null);
        newSection();
        squiffy.story.section = squiffy.story.sections[section];
        if (!squiffy.story.section) return;
        squiffy.set('_section', section);
        setSeen(section);
        var master = squiffy.story.sections[''];
        if (master) {
            squiffy.story.run(master);
            squiffy.ui.write(master.text);
        }
        squiffy.story.run(squiffy.story.section);
        // The JS might have changed which section we're in
        if (squiffy.get('_section') == section) {
            squiffy.set('_turncount', 0);
            squiffy.ui.write(squiffy.story.section.text);
            squiffy.story.save();
        }
    };

    squiffy.story.run = function(section) {
        if (section.clear) {
            squiffy.ui.clearScreen();
        }
        if (section.attributes) {
            processAttributes(section.attributes);
        }
        if (section.js) {
            section.js();
        }
    };

    squiffy.story.passage = function(passageName) {
        var passage = squiffy.story.section.passages[passageName];
        if (!passage) return;
        setSeen(passageName);
        var masterSection = squiffy.story.sections[''];
        if (masterSection) {
            var masterPassage = masterSection.passages[''];
            if (masterPassage) {
                squiffy.story.run(masterPassage);
                squiffy.ui.write(masterPassage.text);
            }
        }
        var master = squiffy.story.section.passages[''];
        if (master) {
            squiffy.story.run(master);
            squiffy.ui.write(master.text);
        }
        squiffy.story.run(passage);
        squiffy.ui.write(passage.text);
        squiffy.story.save();
    };

    var processAttributes = function(attributes) {
        attributes.forEach(function (attribute) {
            if (startsWith(attribute, '@replace ')) {
                replaceLabel(attribute.substring(9));
            }
            else {
                setAttribute(attribute);
            }
        });
    };

    squiffy.story.restart = function() {
        if (squiffy.ui.settings.persist && window.localStorage) {
            var keys = Object.keys(localStorage);
            jQuery.each(keys, function (idx, key) {
                if (startsWith(key, squiffy.story.id)) {
                    localStorage.removeItem(key);
                }
            });
        }
        else {
            squiffy.storageFallback = {};
        }
        if (squiffy.ui.settings.scroll === 'element') {
            squiffy.ui.output.html('');
            squiffy.story.begin();
        }
        else {
            location.reload();
        }
    };

    squiffy.story.save = function() {
        squiffy.set('_output', squiffy.ui.output.html());
    };

    squiffy.story.load = function() {
        var output = squiffy.get('_output');
        if (!output) return false;
        squiffy.ui.output.html(output);
        currentSection = jQuery('#' + squiffy.get('_output-section'));
        squiffy.story.section = squiffy.story.sections[squiffy.get('_section')];
        var transition = squiffy.get('_transition');
        if (transition) {
            eval('(' + transition + ')()');
        }
        return true;
    };

    var setSeen = function(sectionName) {
        var seenSections = squiffy.get('_seen_sections');
        if (!seenSections) seenSections = [];
        if (seenSections.indexOf(sectionName) == -1) {
            seenSections.push(sectionName);
            squiffy.set('_seen_sections', seenSections);
        }
    };

    squiffy.story.seen = function(sectionName) {
        var seenSections = squiffy.get('_seen_sections');
        if (!seenSections) return false;
        return (seenSections.indexOf(sectionName) > -1);
    };
    
    squiffy.ui = {};

    var currentSection = null;
    var screenIsClear = true;
    var scrollPosition = 0;

    var newSection = function() {
        if (currentSection) {
            disableLink(jQuery('.squiffy-link', currentSection));
        }
        var sectionCount = squiffy.get('_section-count') + 1;
        squiffy.set('_section-count', sectionCount);
        var id = 'squiffy-section-' + sectionCount;
        currentSection = jQuery('<div/>', {
            id: id,
        }).appendTo(squiffy.ui.output);
        squiffy.set('_output-section', id);
    };

    squiffy.ui.write = function(text) {
        screenIsClear = false;
        scrollPosition = squiffy.ui.output.height();
        currentSection.append(jQuery('<div/>').html(squiffy.ui.processText(text)));
        squiffy.ui.scrollToEnd();
    };

    squiffy.ui.clearScreen = function() {
        squiffy.ui.output.html('');
        screenIsClear = true;
        newSection();
    };

    squiffy.ui.scrollToEnd = function() {
        var scrollTo, currentScrollTop, distance, duration;
        if (squiffy.ui.settings.scroll === 'element') {
            scrollTo = squiffy.ui.output[0].scrollHeight - squiffy.ui.output.height();
            currentScrollTop = squiffy.ui.output.scrollTop();
            if (scrollTo > currentScrollTop) {
                distance = scrollTo - currentScrollTop;
                duration = distance / 0.4;
                squiffy.ui.output.stop().animate({ scrollTop: scrollTo }, duration);
            }
        }
        else {
            scrollTo = scrollPosition;
            currentScrollTop = Math.max(jQuery('body').scrollTop(), jQuery('html').scrollTop());
            if (scrollTo > currentScrollTop) {
                var maxScrollTop = jQuery(document).height() - jQuery(window).height();
                if (scrollTo > maxScrollTop) scrollTo = maxScrollTop;
                distance = scrollTo - currentScrollTop;
                duration = distance / 0.5;
                jQuery('body,html').stop().animate({ scrollTop: scrollTo }, duration);
            }
        }
    };

    squiffy.ui.processText = function(text) {
        function process(text, data) {
            var containsUnprocessedSection = false;
            var open = text.indexOf('{');
            var close;
            
            if (open > -1) {
                var nestCount = 1;
                var searchStart = open + 1;
                var finished = false;
             
                while (!finished) {
                    var nextOpen = text.indexOf('{', searchStart);
                    var nextClose = text.indexOf('}', searchStart);
         
                    if (nextClose > -1) {
                        if (nextOpen > -1 && nextOpen < nextClose) {
                            nestCount++;
                            searchStart = nextOpen + 1;
                        }
                        else {
                            nestCount--;
                            searchStart = nextClose + 1;
                            if (nestCount === 0) {
                                close = nextClose;
                                containsUnprocessedSection = true;
                                finished = true;
                            }
                        }
                    }
                    else {
                        finished = true;
                    }
                }
            }
            
            if (containsUnprocessedSection) {
                var section = text.substring(open + 1, close);
                var value = processTextCommand(section, data);
                text = text.substring(0, open) + value + process(text.substring(close + 1), data);
            }
            
            return (text);
        }

        function processTextCommand(text, data) {
            if (startsWith(text, 'if ')) {
                return processTextCommand_If(text, data);
            }
            else if (startsWith(text, 'else:')) {
                return processTextCommand_Else(text, data);
            }
            else if (startsWith(text, 'label:')) {
                return processTextCommand_Label(text, data);
            }
            else if (/^rotate[: ]/.test(text)) {
                return processTextCommand_Rotate('rotate', text, data);
            }
            else if (/^sequence[: ]/.test(text)) {
                return processTextCommand_Rotate('sequence', text, data);   
            }
            else if (text in squiffy.story.section.passages) {
                return process(squiffy.story.section.passages[text].text, data);
            }
            else if (text in squiffy.story.sections) {
                return process(squiffy.story.sections[text].text, data);
            }
			else if (startsWith(text,'@') && !startsWith(text,'@replace')) {
				processAttributes(text.substring(1).split(","));
				return "";
			}
            return squiffy.get(text);
        }

        function processTextCommand_If(section, data) {
            var command = section.substring(3);
            var colon = command.indexOf(':');
            if (colon == -1) {
                return ('{if ' + command + '}');
            }

            var text = command.substring(colon + 1);
            var condition = command.substring(0, colon);
			condition = condition.replace("<", "&lt;");
            var operatorRegex = /([\w ]*)(=|&lt;=|&gt;=|&lt;&gt;|&lt;|&gt;)(.*)/;
            var match = operatorRegex.exec(condition);

            var result = false;

            if (match) {
                var lhs = squiffy.get(match[1]);
                var op = match[2];
                var rhs = match[3];

				if(startsWith(rhs,'@')) rhs=squiffy.get(rhs.substring(1));
				
                if (op == '=' && lhs == rhs) result = true;
                if (op == '&lt;&gt;' && lhs != rhs) result = true;
                if (op == '&gt;' && lhs > rhs) result = true;
                if (op == '&lt;' && lhs < rhs) result = true;
                if (op == '&gt;=' && lhs >= rhs) result = true;
                if (op == '&lt;=' && lhs <= rhs) result = true;
            }
            else {
                var checkValue = true;
                if (startsWith(condition, 'not ')) {
                    condition = condition.substring(4);
                    checkValue = false;
                }

                if (startsWith(condition, 'seen ')) {
                    result = (squiffy.story.seen(condition.substring(5)) == checkValue);
                }
                else {
                    var value = squiffy.get(condition);
                    if (value === null) value = false;
                    result = (value == checkValue);
                }
            }

            var textResult = result ? process(text, data) : '';

            data.lastIf = result;
            return textResult;
        }

        function processTextCommand_Else(section, data) {
            if (!('lastIf' in data) || data.lastIf) return '';
            var text = section.substring(5);
            return process(text, data);
        }

        function processTextCommand_Label(section, data) {
            var command = section.substring(6);
            var eq = command.indexOf('=');
            if (eq == -1) {
                return ('{label:' + command + '}');
            }

            var text = command.substring(eq + 1);
            var label = command.substring(0, eq);

            return '<span class="squiffy-label-' + label + '">' + process(text, data) + '</span>';
        }

        function processTextCommand_Rotate(type, section, data) {
            var options;
            var attribute = '';
            if (section.substring(type.length, type.length + 1) == ' ') {
                var colon = section.indexOf(':');
                if (colon == -1) {
                    return '{' + section + '}';
                }
                options = section.substring(colon + 1);
                attribute = section.substring(type.length + 1, colon);
            }
            else {
                options = section.substring(type.length + 1);
            }
            var rotation = rotate(options.replace(/"/g, '&quot;').replace(/'/g, '&#39;'));
            if (attribute) {
                squiffy.set(attribute, rotation[0]);
            }
            return '<a class="squiffy-link" data-' + type + '="' + rotation[1] + '" data-attribute="' + attribute + '" role="link">' + rotation[0] + '</a>';
        }

        var data = {
            fulltext: text
        };
        return process(text, data);
    };

    squiffy.ui.transition = function(f) {
        squiffy.set('_transition', f.toString());
        f();
    };

    squiffy.storageFallback = {};

    squiffy.set = function(attribute, value) {
        if (typeof value === 'undefined') value = true;
        if (squiffy.ui.settings.persist && window.localStorage) {
            localStorage[squiffy.story.id + '-' + attribute] = JSON.stringify(value);
        }
        else {
            squiffy.storageFallback[attribute] = JSON.stringify(value);
        }
        squiffy.ui.settings.onSet(attribute, value);
    };

    squiffy.get = function(attribute) {
        var result;
        if (squiffy.ui.settings.persist && window.localStorage) {
            result = localStorage[squiffy.story.id + '-' + attribute];
        }
        else {
            result = squiffy.storageFallback[attribute];
        }
        if (!result) return null;
        return JSON.parse(result);
    };

    var startsWith = function(string, prefix) {
        return string.substring(0, prefix.length) === prefix;
    };

    var rotate = function(options, current) {
        var colon = options.indexOf(':');
        if (colon == -1) {
            return [options, current];
        }
        var next = options.substring(0, colon);
        var remaining = options.substring(colon + 1);
        if (current) remaining += ':' + current;
        return [next, remaining];
    };

    var methods = {
        init: function (options) {
            var settings = jQuery.extend({
                scroll: 'body',
                persist: true,
                restartPrompt: true,
                onSet: function (attribute, value) {}
            }, options);

            squiffy.ui.output = this;
            squiffy.ui.restart = jQuery(settings.restart);
            squiffy.ui.settings = settings;

            if (settings.scroll === 'element') {
                squiffy.ui.output.css('overflow-y', 'auto');
            }

            initLinkHandler();
            squiffy.story.begin();
            
            return this;
        },
        get: function (attribute) {
            return squiffy.get(attribute);
        },
        set: function (attribute, value) {
            squiffy.set(attribute, value);
        },
        restart: function () {
            if (!squiffy.ui.settings.restartPrompt || confirm('Are you sure you want to restart?')) {
                squiffy.story.restart();
            }
        }
    };

    jQuery.fn.squiffy = function (methodOrOptions) {
        if (methods[methodOrOptions]) {
            return methods[methodOrOptions]
                .apply(this, Array.prototype.slice.call(arguments, 1));
        }
        else if (typeof methodOrOptions === 'object' || ! methodOrOptions) {
            return methods.init.apply(this, arguments);
        } else {
            jQuery.error('Method ' +  methodOrOptions + ' does not exist');
        }
    };
})();

var get = squiffy.get;
var set = squiffy.set;


squiffy.story.start = '_default';
squiffy.story.id = '27aad2273f';
squiffy.story.sections = {
	'_default': {
		'text': "<p>You are the King of <a class=\"squiffy-link link-section\" data-section=\"Xanadu\" role=\"link\" tabindex=\"0\">Xanadu</a>.</p>",
		'passages': {
		},
	},
	'Xanadu': {
		'text': "<p>And what a lovely place. The fields surge with life. Rivers twirl through the tumbling hills like veins in a grand muscle, unwinding into your harbours, which throng with trading fleets and grow about them the holy lichen of your vast, marble cities.</p>\n<p>The people, even the lowliest servants, work comfortable hours and live comfortable lives. Their souls surge with kindness, and no man ever goes in want of food. The roads to the capital throng with travellers, and lush forests roll down proud mountains to be joined with the gardens of your <a class=\"squiffy-link link-section\" data-section=\"palace\" role=\"link\" tabindex=\"0\">palace</a>.</p>",
		'passages': {
		},
	},
	'palace': {
		'text': "<p>And your palace! Some still believe it was stolen from heaven. Those grand, silvered temples and sprawling houses of art, through which the greatest minds of the world make pilgrimage. The eastern walls look over a stunning ocean bay, Sunlight flows through the wide-arch windows, and the sounds of the sea course gently through the halls. </p>\n<p>A fitting heart for such a grand kingdom - the kingdom that conquerors and warlords have dreamed of for centuries, the kingdom that found them all wanting. <a class=\"squiffy-link link-section\" data-section=\"Morning\" role=\"link\" tabindex=\"0\">Xanadu</a>.</p>",
		'passages': {
		},
	},
	'Morning': {
		'text': "<p>On this morning it is a grand day, as they all are in Xanadu. No clouds trespass in your perfect sky. The fishing boats move out to start the day&#39;s work, scattering pearlwhite trails across the opal sea. You walk through the palace halls in the robes of your station with hands clasped thoughtfully behind your back.</p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Gardens\" role=\"link\" tabindex=\"0\">Inspect the gardens.</a></p>",
		'passages': {
		},
	},
	'Gardens': {
		'clear': true,
		'text': "<p>The newest installation to the palace gardens is a verdant grove, bright flowers tangling with sun-soaked grass and shadowed by a vast, imported elm.\nit was built by a very accomplished architect who has spent his whole life vying for the opportunity. The consensus is that it will make a fine and respectable addition to the estate, but as always we wait for your <a class=\"squiffy-link link-section\" data-section=\"verdict\" role=\"link\" tabindex=\"0\">verdict</a>.</p>",
		'passages': {
		},
	},
	'verdict': {
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"Uneven\" role=\"link\" tabindex=\"0\">The grass should be more even.</a></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Stream\" role=\"link\" tabindex=\"0\">It would look better with a stream.</a></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Ugly\" role=\"link\" tabindex=\"0\">The garden is ugly. Destroy it.</a></p>",
		'passages': {
		},
	},
	'Uneven': {
		'text': "<p>It is so.\nAt noon, gardeners descend on the grass and cut it all down to regulation height, to a level meeting your standards of orderliness. We are confident that all who now visit it will be reminded of your kingdom&#39;s perfect and orderly <a class=\"squiffy-link link-section\" data-section=\"Morning2\" role=\"link\" tabindex=\"0\">nature</a>.</p>",
		'passages': {
		},
	},
	'Stream': {
		'text': "<p>it is so.\nThe elm is transplanted elsewhere and, in its place, a trench is dug through the centre of the grove. Water is brought up from the sea and is led through the glade by a trench. The new stream, as you no doubt predicted, elevates what was otherwise quite an ordinary garden up to the highest standards of beauty. </p>\n<p>There is talk of extending the stream further into the gardens, and in the meanwhile, you have given employment to the dozen servants who now day and night work the pumps that bring the <a class=\"squiffy-link link-section\" data-section=\"Morning2\" role=\"link\" tabindex=\"0\">water</a>.</p>",
		'passages': {
		},
	},
	'Ugly': {
		'text': "<p>It is so.\nThe plants are uprooted immediately and the soil is paved over with limestone. The elm is made firewood. An investigation is carried out into how we could have allowed such an ugly patch of dirt to occupy the palace grounds, and in the architect&#39;s past we find crimes against morality. You are commended, our king, for protecting our gardens from <a class=\"squiffy-link link-section\" data-section=\"Morning2\" role=\"link\" tabindex=\"0\">degeneracy</a>.</p>",
		'passages': {
		},
	},
	'Morning2': {
		'clear': true,
		'text': "<p>Sunrise again. The army awaits <a class=\"squiffy-link link-section\" data-section=\"inspection\" role=\"link\" tabindex=\"0\">inspection</a>.</p>",
		'passages': {
		},
	},
	'inspection': {
		'text': "<p>You stand at a high marble balcony. The finest legion of the capital garrison postulates itself before you, far below. Fifty thousand men, aligned perfectly in endless rows in the endless green of a garden courtyard (it is like a canyon, a corridor of the earth). The tips of their pikes are a bed of nails that would prick the hand of God. They stand silent and await your <a class=\"squiffy-link link-section\" data-section=\"command\" role=\"link\" tabindex=\"0\">command</a>.</p>",
		'passages': {
		},
	},
	'command': {
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"Fight\" role=\"link\" tabindex=\"0\">Split them into two halves and have them fight against each other.</a></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Dance\" role=\"link\" tabindex=\"0\">Have them dance like apes.</a></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Breakfast\" role=\"link\" tabindex=\"0\">Give no orders and return to the dining hall.</a></p>",
		'passages': {
		},
	},
	'Fight': {
		'text': "<p>It is so.\nThe two halves form up and march on each other. They batttle for several hours while your nobles gather silently and watch from the balconies. There is a disturbed atmosphere among the observers.</p>\n<p>Clearly, however, your wisdom has provided a powerful and captivating demonstration of your army&#39;s vigor, and the few casualties were obviously the weakest of your forces, only sharpening the legion with their passing. The courtyard is cleaned and again ready for visitors by the following <a class=\"squiffy-link link-section\" data-section=\"Morning3\" role=\"link\" tabindex=\"0\">morning</a>.</p>",
		'passages': {
		},
	},
	'Dance': {
		'text': "<p>For your amusement, of course. \nThey are at first uncertain, but once the lieutenants shout and the officers relay the command, the vast, rigid machinery of the great military mechanism begins to turn unnering and before long the entire mass of men is throwing their arms up and jumping from leg to leg. When ordered to, they holler, hooting together like a horde of nature&#39;s finest and most decorated beasts. Pikes and rifles are hurled into the air, and the nobility, drunk and laughing, reach down from their balconies (not as high as yours, of course!) to grab at them.\nOur army is surely very thankful to have been able to offer such lovely <a class=\"squiffy-link link-section\" data-section=\"Morning3\" role=\"link\" tabindex=\"0\">entertainment</a>.</p>",
		'passages': {
		},
	},
	'Breakfast': {
		'text': "<p>It is so.\nFor breakfast, you are served rich game layered with wild spices, hard-boiled eggs from an exotic bird only recently discovered by your kingdom&#39;s natural philosophers, and bread dipped in honeyed milk. Outside, in the courtyard, the soldiers remain in formation, only collapsing with exhaustion in the late evening. You have given our soldiers a generous chance to prove their discipline, for which they are surely thankful.\nThe eggs are <a class=\"squiffy-link link-section\" data-section=\"Morning3\" role=\"link\" tabindex=\"0\">satisfactory</a>.</p>",
		'passages': {
		},
	},
	'Morning3': {
		'clear': true,
		'text': "<p>Another morning. The sun is here again, and so is <a class=\"squiffy-link link-section\" data-section=\"Summer\" role=\"link\" tabindex=\"0\">Summer</a>.</p>",
		'passages': {
		},
	},
	'Summer': {
		'text': "<p>Summer over Xanadu.\nXanadu, the kingdom that only grows in size.\nXanadu, the kingdom in the middle of every map.\nXanadu, the kingdom from which all roads stem and into which all roads <a class=\"squiffy-link link-section\" data-section=\"feed\" role=\"link\" tabindex=\"0\">feed</a>.</p>",
		'passages': {
		},
	},
	'feed': {
		'text': "<p>It is Solstice-eve, time for the yearly harvest. A momentous occasion. The people perform the usual celebrations. Red cloth is hung from balconies. Young children paint bouys the colours of daydreams and set them out to sea. Elders with lit candles parade through the capital, singing the old songs, winding through the streets like ancient snakes. And, lastly, arithmaticians take out tablets and chalk, ready to count and divy the grain of the harvest.</p>\n<p>Vessels dock at all the ports of your kingdom, eager to take with them our leftover crop and disperse it among the lesser nations of the world.\nBut before anything, you must bless and oversee the harvest of a nearby field, as tradition <a class=\"squiffy-link link-section\" data-section=\"demands\" role=\"link\" tabindex=\"0\">demands</a>.</p>",
		'passages': {
		},
	},
	'demands': {
		'text': "<p>The peasants bow their heads as you pass.  A harvestman slices off a stalk from the crop and kneels before you. He unpeels the head, so you may bless the enclosed <a class=\"squiffy-link link-section\" data-section=\"grain\" role=\"link\" tabindex=\"0\">grain</a>.</p>",
		'passages': {
		},
	},
	'grain': {
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"There is something wrong\" role=\"link\" tabindex=\"0\">There is something wrong</a>.</p>",
		'passages': {
		},
	},
	'There is something wrong': {
		'text': "<p>The grain of this stalk is <a class=\"squiffy-link link-passage\" data-passage=\"shrivelled\" role=\"link\" tabindex=\"0\">shrivelled</a> and <a class=\"squiffy-link link-passage\" data-passage=\"blackened\" role=\"link\" tabindex=\"0\">blackened</a>.</p>",
		'passageCount': 2,
		'passages': {
			'shrivelled': {
				'text': "<p>Weak, malnourished. A sickly calf, cursed by the moon, braying with two heads. Barren as the skin of a man collapsed in the desert, mouth opening, closing, tongue pressing into the sand, left eye looking upward, looking for water. But there is only the sun, the terrible ball of heat and fire. Summer over Xanadu.</p>\n<p>In short: the grain is inedible.</p>",
			},
			'blackened': {
				'text': "<p>Rotten, poisoned, altered. Flaming oil from forbidden places under the world. A peasant&#39;s lungs, choked with ash from the silver mines. Sin living in the heart of a man, pumped around the body, soaking into muscle, spilling as tar from the eyes and mouth. Liable to spread. </p>\n<p>In short: the grain is sickened.</p>",
			},
			'@last': {
				'text': "<p>In short, <a class=\"squiffy-link link-section\" data-section=\"dead\" role=\"link\" tabindex=\"0\">dead</a>.</p>",
			},
		},
	},
	'dead': {
		'text': "<p>You inspect the grains closer. They are putrefied: oily, sticky, almost liquid. They carry an offensive odour, the mark of sickness.\nAn unfortunate choice for the first crop of the season. We should wait, my king, whilst the men select another stalk from the field. Our apologies for this <a class=\"squiffy-link link-section\" data-section=\"incident\" role=\"link\" tabindex=\"0\">incident</a>.</p>",
		'passages': {
		},
	},
	'incident': {
		'text': "<p>The second stalk they bring up to you is similarly affected. As is the next, and the next, and the next. The men grow puzzled, then concerned. This entire field is <a class=\"squiffy-link link-section\" data-section=\"rotten\" role=\"link\" tabindex=\"0\">rotten</a>.</p>",
		'passages': {
		},
	},
	'rotten': {
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"fields\" role=\"link\" tabindex=\"0\">But I don&#39;t want rotten fields. I want fields brimming with life and crop! Where are those fields? Find me those fields!</a></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Mockery\" role=\"link\" tabindex=\"0\">Xanadu does not bear ill fruits. This is clearly a deception by the peasants in an attempt to mock me and my kingdom.</a></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Blessing\" role=\"link\" tabindex=\"0\">If this is the grain the gods have given us, then it is the grain we shall eat.</a></p>",
		'passages': {
		},
	},
	'fields': {
		'text': "<p>Our procession moves to a nearby field to repeat the ceremony. Then <a class=\"squiffy-link link-section\" data-section=\"another\" role=\"link\" tabindex=\"0\">another</a>.</p>",
		'passages': {
		},
	},
	'another': {
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"another2\" role=\"link\" tabindex=\"0\">Another</a>.</p>",
		'passages': {
		},
	},
	'another2': {
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"Another still\" role=\"link\" tabindex=\"0\">Another still</a>.</p>",
		'passages': {
		},
	},
	'Another still': {
		'text': "<p>We go from farmland to farmland, but in every field, the stalks they peel back are filled with black, rotting grain. Our company are as perplexed as the farmers themselves (none are permitted to examine a stalk before you have called the harvest, lest the field be contaminated by improper observation). After several hours of wandering, we find no stalks suitable for your blessing, your majesty.\nThis is troubling. Officers will be dispatched to investigate fields in the surrounding provinces. The harvest will have to be delayed, of course, but we are confident that before long our ministries will determine the scale of the <a class=\"squiffy-link link-section\" data-section=\"Morning4\" role=\"link\" tabindex=\"0\">problem</a>.</p>",
		'passages': {
		},
	},
	'Mockery': {
		'text': "<p>Lying to the king is a serious crime. Our knights draw their swords and dispense the requisite <a class=\"squiffy-link link-section\" data-section=\"justice\" role=\"link\" tabindex=\"0\">justice</a>.</p>",
		'passages': {
		},
	},
	'justice': {
		'text': "<p>How heinous - corrupting this most merry of occasions, attempting to humiliate a king, forcing us to make them martyrs. They must have poisoned the soil somehow - to make it produce bad stalks. But our investigations reveal no poison of any kind, nor any other sign of human interference that would cause grain to rot in this way.\nOur officers will inspect the neighbouring provinces to determine the cause and scale of these rotten crops, and will apprehend those responsible.\nIn the meanwhile, this field will be well fertilised by the blood of its tenders. Next year, the soil will hopefully produce a more nourished <a class=\"squiffy-link link-section\" data-section=\"Morning4\" role=\"link\" tabindex=\"0\">crop</a>.</p>",
		'passages': {
		},
	},
	'Blessing': {
		'text': "<p>It is so.\nAn attendant strips the stalk and pours the <a class=\"squiffy-link link-passage\" data-passage=\"grain\" role=\"link\" tabindex=\"0\">grain</a> into your <a class=\"squiffy-link link-section\" data-section=\"hands\" role=\"link\" tabindex=\"0\">hands</a>.</p>",
		'passages': {
			'grain': {
				'text': "<p>(Parts of it flake off onto your fingers, leaving behind a sticky residue. Very bold of the earth, to excrete this stuff, and in Xanadu, no less.)</p>",
			},
		},
	},
	'hands': {
		'text': "<p>You raise it up and speak a small prayer. The standard fare: you ask the gods that the grain be well received, that it be blessed by the Hearth Mother and carry with it the glory of the stars, that there be more of it. More grain like this, more grain touched by the sun.</p>\n<p>After your blessing, a small collection of parrots are released and peck the grain from your hands, as it is the duty of the king to feed the beasts of Xanadu even as he feeds the <a class=\"squiffy-link link-section\" data-section=\"people\" role=\"link\" tabindex=\"0\">people</a>.</p>",
		'passages': {
		},
	},
	'people': {
		'text': "<p>The blessing is complete. The peasants excitedly begin slicing the stalks, growing confused when they split the heads and all the grain that spills out is black.</p>\n<p>You turn and leave, your procession of knights and consorts and courtiers marching alongside at a respectful distance. </p>\n<p>As you pass more fields, peasants raise their sickles in salute and cheer, eager to begin the harvest of the new year. Our messengers will disperse across the kingdom, and announce that the great harvest has begun again.</p>\n<p>You look down and notice four dead parrots lying in the grass.\nThe closest bird has its left eye open - beady black pupil looking up at the sky, looking for the <a class=\"squiffy-link link-section\" data-section=\"Morning4\" role=\"link\" tabindex=\"0\">sun</a>.</p>",
		'passages': {
		},
	},
	'Morning4': {
		'clear': true,
		'text': "<p>You have begun to loathe the morning. The sun hurts your eyes. That kind of behaviour is a sign of disloyalty. But you only need to bide your time, and summer will be over before long. And until then, at least the moon remains obedient, never threatening to outshine you with its modest, respectful <a class=\"squiffy-link link-section\" data-section=\"glow\" role=\"link\" tabindex=\"0\">glow</a>.</p>",
		'passages': {
		},
	},
	'glow': {
		'text': "<p>We apologise, our king, but we have worrisome news for you. The sickly crop was not an isolated incident. Reports from all across the kingdom emerge - of good stalks yielding only black grain, entire fields fill of death and rot.\nIt seems that almost all of Xanadu&#39;s harvest grain has been struck by a terrible pestilence. The harvest returns only scraps. That grain was to feed the mouths of the kingdom for an entire year, and  without it, our people find themselves with only leftovers from prior seasons. It seems very likely that we are at the precipice of a <a class=\"squiffy-link link-section\" data-section=\"famine\" role=\"link\" tabindex=\"0\">famine</a>.</p>",
		'passages': {
		},
	},
	'famine': {
		'text': "<p>For a hundred hundred years, Xanadu has known only prosperity. We assume that any problem that emerges will resolve itself quickly, but this situation has no real precedence...</p>\n<p>We ask of you to make a decision.\nWe have gathered some of the most esteemned advisors in your court. We do not doubt the greatness of your endless wisdom, but you could draw from their <a class=\"squiffy-link link-passage\" data-passage=\"advice\" role=\"link\" tabindex=\"0\">advice</a> in your <a class=\"squiffy-link link-passage\" data-passage=\"deliberation\" role=\"link\" tabindex=\"0\">deliberation</a>.</p>",
		'passages': {
			'advice': {
				'text': "<p><a class=\"squiffy-link link-passage\" data-passage=\"statistician\" role=\"link\" tabindex=\"0\">Hear the wisdom of the royal statistician.</a></p>\n<p><a class=\"squiffy-link link-passage\" data-passage=\"general\" role=\"link\" tabindex=\"0\">Hear the wisdom of a grand general of the legion.</a></p>\n<p><a class=\"squiffy-link link-passage\" data-passage=\"professor\" role=\"link\" tabindex=\"0\">Hear the wisdom of an esteemed scholar from the Academy of Natural Philosophy.</a></p>",
			},
			'statistician': {
				'text': "<p>&#39;With our fields all taken by blight, the only bread with which we can feed our people must come from the leftover grain of last year&#39;s harvest. The obvious decision is to take stock of these remnants and evaluate their number. This will allow us to ensure a fair distribution of scarce resources.&#39;</p>",
			},
			'general': {
				'text': "<p>&#39;It is important in these times to remind the people that the government is in control of the situation. They will be panicked and scared. To prevent looting, we should deploy our army as a peacekeeping force, to preserve a sense of order and to safegaurd our communities.&#39;</p>",
			},
			'professor': {
				'text': "<p>&#39;While the immediate effects of this blight must not be ignored, we must consider its impact in the context of nature itself. </p>\n<p>&#39;Modern scientific understanding suggests that many beasts - the sparrows, for example, or the simple mouse - share deep and complex harmonies with the plant species of the wider world, including, yes, even our own crops, which are now dangerously absent from the ecosystem. However we choose to fight this famine, we must watch closely the simple animals of the world and preserve the ecological balance, lest it tip and forever damage the holy equillibrium of nature.&#39;</p>",
			},
			'deliberation': {
				'text': "<p>Have you found us a <a class=\"squiffy-link link-section\" data-section=\"course of action?\" role=\"link\" tabindex=\"0\">course of action?</a></p>",
			},
		},
	},
	'course of action?': {
		'text': "<p>{if seen statistician:<a class=\"squiffy-link link-section\" data-section=\"StatAdv\" role=\"link\" tabindex=\"0\">Follow the advice of the statistician.</a>}</p>\n<p>{if seen general:<a class=\"squiffy-link link-section\" data-section=\"GenAdv\" role=\"link\" tabindex=\"0\">Follow the advice of the general.</a>}</p>\n<p>{if seen professor:<a class=\"squiffy-link link-section\" data-section=\"ProfAdv\" role=\"link\" tabindex=\"0\">Follow the advice of the scholar.</a>}</p>\n<p><a class=\"squiffy-link link-section\" data-section=\"SelfAdv\" role=\"link\" tabindex=\"0\">I am the King, and my voice carries louder than that of any mere mortal. I follow only my own advice.</a></p>",
		'passages': {
		},
	},
	'StatAdv': {
		'text': "<p>The statistician is of course correct. We must hand out this grain fairly - to those who deserve it most. The farmers, whose laziness has allowed this pestilence to destroy the nation&#39;s food under their feet, their grain will be rationed last, after the hardworking people of <a class=\"squiffy-link link-section\" data-section=\"Fam1\" role=\"link\" tabindex=\"0\">Xanadu</a>.</p>",
		'passages': {
		},
	},
	'GenAdv': {
		'text': "<p>The general has some good ideas. Withdrawl our military to the Capital. Bar the gates, and kill any who attempt to force entry. Make no mistake, we will be in control, in total control, of this crisis, and <a class=\"squiffy-link link-section\" data-section=\"Fam1\" role=\"link\" tabindex=\"0\">everything more besides.</a></p>",
		'passages': {
		},
	},
	'ProfAdv': {
		'text': "<p>Of course! This famine was caused by a pestilence, a simple disease. And what greater spreader of disease is there than the common, filthy animal? The rat, scuttling between the stalks, and the sparrow, perched on the head of a stalk to preen itself, shaking the fragments of evil from its feathers, letting them settle on our good food, chattering in birdtongue at the subtlety of its cleverness.\nYes, the scholar is correct. We have not been watching the beasts closely enough. We shall tolerate their sabotage no longer, for carrying the enemy upon their backs. Ten guilders for the head of every household pest, any simple beast that dares take a single step into our fields! Send the legion! I want the sparrows speared, I want the rabbits hung! No mercy for the enemies of <a class=\"squiffy-link link-section\" data-section=\"Fam1\" role=\"link\" tabindex=\"0\">Xanadu</a>!</p>",
		'passages': {
		},
	},
	'SelfAdv': {
		'text': "<p>Now; You speak of terrible pestilence, of inbound famines. Of fear and suffering. \nBut when I look outside, I see only the kingdom and its people, all in perfect operation. I see no fear, no suffering, and not in the last hundred years has there been anything but peace in Xanadu.</p>\n<p>We will do nothing, and endure whatever minor discomforts may be on their way, if they even arrive at all, as the people of Xanadu <a class=\"squiffy-link link-section\" data-section=\"Fam1\" role=\"link\" tabindex=\"0\">have always done</a>.</p>",
		'passages': {
		},
	},
	'Fam1': {
		'clear': true,
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"Fam2\" role=\"link\" tabindex=\"0\">...</a></p>",
		'passages': {
		},
	},
	'Fam2': {
		'clear': true,
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"Fam3\" role=\"link\" tabindex=\"0\">It moves slowly at first.</a></p>",
		'passages': {
		},
	},
	'Fam3': {
		'clear': true,
		'text': "<p>Slowly, and with the unstoppable sureness of <a class=\"squiffy-link link-section\" data-section=\"Fam4\" role=\"link\" tabindex=\"0\">midday heat.</a></p>",
		'passages': {
		},
	},
	'Fam4': {
		'text': "<p>In the first few days, the people remain calm. Even without the grain, Xanadu grows many fruits and vegetables, which for the time being sustains the people alongside last year&#39;s remnant harvest. Where necessary, animals are slaughtered. There are the looming omens of catastrophe, but it merely laps at our ankles<a class=\"squiffy-link link-section\" data-section=\"Fam5\" role=\"link\" tabindex=\"0\">...</a></p>",
		'passages': {
		},
	},
	'Fam5': {
		'clear': true,
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"Fam6\" role=\"link\" tabindex=\"0\">This does not last.</a></p>",
		'passages': {
		},
	},
	'Fam6': {
		'clear': true,
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"Fam7\" role=\"link\" tabindex=\"0\">Hunger.</a></p>",
		'passages': {
		},
	},
	'Fam7': {
		'clear': true,
		'text': "<p>It emerges from the soil, welling up from beneath dirt streets, flowing across towns and villages. It hides in empty carts and perches in dead trees. The people climb on top of grain silos, lock themselves in food storehouses, trying to escape. But it finds them all eventually, with endless patience, waiting for them to eat the food before quitely settling into the empty space behind them. When they realise, they flee, looking for something else to eat. But it follows them, always. Hiding in empty barrels, nesting underneath the picked-clean bones of slaughtered cattle. This is the start of the famine. These pockets of hunger. Chasing people from their homes, from their villages, following them as they walk to the cities, sleeping in their empty stomachs as they beg for asylum.</p>\n<p>{if seen StatAdv:<a class=\"squiffy-link link-section\" data-section=\"Fam8\" role=\"link\" tabindex=\"0\">For their failure, the farmers are left to starve outside the gates.</a>}</p>\n<p>{if seen GenAdv:<a class=\"squiffy-link link-section\" data-section=\"Fam8\" role=\"link\" tabindex=\"0\">At the gates, spear-tips go red.</a>}</p>\n<p>{if seen ProfAdv:<a class=\"squiffy-link link-section\" data-section=\"Fam8\" role=\"link\" tabindex=\"0\">The air is choked with buzzing insects.</a>}</p>\n<p>{if seen SelfAdv:<a class=\"squiffy-link link-section\" data-section=\"Fam8\" role=\"link\" tabindex=\"0\">The capital&#39;s gates remain closed.</a>}</p>",
		'passages': {
		},
	},
	'Fam8': {
		'clear': true,
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"Fam9\" role=\"link\" tabindex=\"0\">Autumn.</a></p>",
		'passages': {
		},
	},
	'Fam9': {
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"Fam10\" role=\"link\" tabindex=\"0\">The famine continues.</a></p>",
		'passages': {
		},
	},
	'Fam10': {
		'text': "<p>Dozens of men enter your halls every day, of great station, or great intellect, as many as you can tolerate. They each propose their solutions to the <a class=\"squiffy-link link-section\" data-section=\"crisis\" role=\"link\" tabindex=\"0\">crisis</a>.</p>",
		'passages': {
		},
	},
	'crisis': {
		'text': "<p>They unfold their great ideas, each drawing from myriad fields and theories. Plans of <a class=\"squiffy-link link-section\" data-section=\"Fam11\" role=\"link\" tabindex=\"0\">diplomacy</a>, <a class=\"squiffy-link link-section\" data-section=\"Fam11\" role=\"link\" tabindex=\"0\">organisation</a>, <a class=\"squiffy-link link-section\" data-section=\"Fam11\" role=\"link\" tabindex=\"0\">economics</a>, <a class=\"squiffy-link link-section\" data-section=\"Fam11\" role=\"link\" tabindex=\"0\">military intercedence</a>, <a class=\"squiffy-link link-section\" data-section=\"Fam11\" role=\"link\" tabindex=\"0\">science</a>, <a class=\"squiffy-link link-section\" data-section=\"Fam11\" role=\"link\" tabindex=\"0\">historical analysis</a>, <a class=\"squiffy-link link-section\" data-section=\"Fam11\" role=\"link\" tabindex=\"0\">inspiration</a>, <a class=\"squiffy-link link-section\" data-section=\"Fam11\" role=\"link\" tabindex=\"0\">prayer</a> and <a class=\"squiffy-link link-section\" data-section=\"Fam11\" role=\"link\" tabindex=\"0\">downright occultism.</a></p>",
		'passages': {
		},
	},
	'Fam11': {
		'clear': true,
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"Fam12\" role=\"link\" tabindex=\"0\">None of them work for long.</a></p>",
		'passages': {
		},
	},
	'Fam12': {
		'clear': true,
		'text': "<p>At times, the famine seems to recede - a stroke of luck, a respite, where the suffering lapses slightly, and the people can stand a little straighter. Some allow this to fill them with hope, but you recognise this only as a natural rhythm of the tides. And the waves always come closer in the <a class=\"squiffy-link link-section\" data-section=\"Vig1\" role=\"link\" tabindex=\"0\">end</a>.</p>",
		'passages': {
		},
	},
	'Vig1': {
		'clear': true,
		'text': "<p>In the western provinces, noble families are accused of hoarding food. Revolts break out. Grand estates are burnt. The looters very rarely find more than a pitiful stock of food, even in the richest houses.</p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Vig2\" role=\"link\" tabindex=\"0\">*</a></p>",
		'passages': {
		},
	},
	'Vig2': {
		'clear': true,
		'text': "<p>Waves of disease emerge across the country, each one a great drumbeat; the drum is made from human skin, and the skin is cracked and chipped from years of impacts. Malnutrition, they say, makes the body greatly vulnerable to maladies, and our kingdom quickly becomes swamped with disease.\nThe sick and dying flood our hospitals. Medicine becomes a rare treasure. But not one as scarce, nowhere near as scarce, as food.</p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Vig3\" role=\"link\" tabindex=\"0\">*</a></p>",
		'passages': {
		},
	},
	'Vig3': {
		'clear': true,
		'text': "<p>The grand city of Aboaran has fallen to civil discontent. The event is described not as a revolution, but as a total disintegration of community. Food grew so expensive that money became practically useless, you see - meaning the citizens simply had no reason to work, and had no choice but to search for food elsewhere. Thousands are abandoning the city as we speak.</p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Vig4\" role=\"link\" tabindex=\"0\">*</a></p>",
		'passages': {
		},
	},
	'Vig4': {
		'clear': true,
		'text': "<p>The people have taken to eating the sickly grain. They press it into a stinking paste and gulp it down like soft cheese. It always comes back up - first the convulsive fits, then a violent emesis of black oil, laced with blood. They keep eating it. What else are they to do?</p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Burst1\" role=\"link\" tabindex=\"0\">*</a></p>",
		'passages': {
		},
	},
	'Burst1': {
		'clear': true,
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"Burst2\" role=\"link\" tabindex=\"0\">These things are happening.</a></p>",
		'passages': {
		},
	},
	'Burst2': {
		'clear': true,
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"Burst3\" role=\"link\" tabindex=\"0\">Faster and faster.</a></p>",
		'passages': {
		},
	},
	'Burst3': {
		'clear': true,
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"Burst4\" role=\"link\" tabindex=\"0\">Something new</a></p>",
		'passages': {
		},
	},
	'Burst4': {
		'clear': true,
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"Burst5\" role=\"link\" tabindex=\"0\">Each day.</a></p>",
		'passages': {
		},
	},
	'Burst5': {
		'clear': true,
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"Burst6\" role=\"link\" tabindex=\"0\">...</a></p>",
		'passages': {
		},
	},
	'Burst6': {
		'clear': true,
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"Dec1\" role=\"link\" tabindex=\"0\">Winter.</a></p>",
		'passages': {
		},
	},
	'Dec1': {
		'clear': true,
		'text': "<p>The famine has reached the capital. Starving peasants gather at the city square, calling out from beneath stained glass windows and bricked-up archways. They beg for you to help them, king, although I fear there is little we can do.</p>\n<p><a class=\"squiffy-link link-section\" data-section=\"FoodRiot\" role=\"link\" tabindex=\"0\">Empty all but one of the palace storehouses and disperse the food among the crowds.</a></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"BadFeast\" role=\"link\" tabindex=\"0\">Hold a feast, in commiseration for their suffering.</a></p>",
		'passages': {
		},
	},
	'FoodRiot': {
		'text': "<p>Grasping hands reach toward the balconies as servants toss down the food. As the white packages are carried away through the sea of hands, fights break out. Hours later, after the palace has given all it can, the crowds are still just as large, reaching upward with a thousand <a class=\"squiffy-link link-section\" data-section=\"Dec2\" role=\"link\" tabindex=\"0\">hands</a>.</p>",
		'passages': {
		},
	},
	'BadFeast': {
		'text': "<p>Before the food, prayers are spoken for the hungry, the sick and the dead. The minister of peacekeeping could not be with us, as he is managing a riot in the hospice district. Dinner is oysters on a bed of wild grapes, served alongside rich pudding. \nThe ex-duke of Aboaran requests pheasant for the second course, but there is no more good meat in the <a class=\"squiffy-link link-section\" data-section=\"Dec2\" role=\"link\" tabindex=\"0\">capital</a>.</p>",
		'passages': {
		},
	},
	'Dec2': {
		'clear': true,
		'text': "<p>They come before your throne and throw themselves down, begging you to save them, save their families. But you can do nothing. The hunger has caught them, and it lives inside them now, in a place so deep it that csnnot be reached. You see the <a class=\"squiffy-link link-section\" data-section=\"Dec3\" role=\"link\" tabindex=\"0\">black behind their eyes</a>.</p>",
		'passages': {
		},
	},
	'Dec3': {
		'clear': true,
		'text': "<p>The capital is in chaos. All soldiers who were once gaurding treasuries are now defending the capital&#39;s last surviving <a class=\"squiffy-link link-section\" data-section=\"Dec4\" role=\"link\" tabindex=\"0\">granaries</a>.</p>",
		'passages': {
		},
	},
	'Dec4': {
		'clear': true,
		'text': "<p>Whatever the cause of the blight that brought this famine upon us, it seems to have poisoned the soil along with the grain. Farmers report that the grain they seeded for the new harvest refuses to grow. We cannot rely on our storehouses to restock themselves over time, and this famine will likely last for years, <a class=\"squiffy-link link-section\" data-section=\"Dec5\" role=\"link\" tabindex=\"0\">at the least</a>.</p>",
		'passages': {
		},
	},
	'Dec5': {
		'clear': true,
		'text': "<p>The riots have broken through the palace gates! They meet our soldiers in the lower lake courtyards. But the legion has the situation fully in hand. You’d be surprised, my king, at how furiously a starving man fights to keep his head above the <a class=\"squiffy-link link-section\" data-section=\"Dec6\" role=\"link\" tabindex=\"0\">water</a>.</p>",
		'passages': {
		},
	},
	'Dec6': {
		'text': "<p>During your morning stroll through the halls, you glance out a window, down at the bay. They&#39;re burning the bodies <a class=\"squiffy-link link-section\" data-section=\"again\" role=\"link\" tabindex=\"0\">again</a>.</p>",
		'passages': {
		},
	},
	'again': {
		'text': "<p>They have to do it quickly, before nightfall, when the <a class=\"squiffy-link link-section\" data-section=\"scavenging begins\" role=\"link\" tabindex=\"0\">scavenging begins</a>.</p>",
		'passages': {
		},
	},
	'scavenging begins': {
		'text': "<p>The currents are no longer sufficient to wash away the bodies. The dead throng the bay, expanding with bloat and gathering about them the miasma of disease. The leakages of their pestilence stain the harbor water <a class=\"squiffy-link link-section\" data-section=\"Dec7\" role=\"link\" tabindex=\"0\">black</a>.</p>",
		'passages': {
		},
	},
	'Dec7': {
		'clear': true,
		'text': "<p>One of our nobles was eaten by a dog.</p>\n<p><a class=\"squiffy-link link-section\" data-section=\"DogRich\" role=\"link\" tabindex=\"0\">Amusing. Assign the dog its own wing in the palace.</a></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"DogDead\" role=\"link\" tabindex=\"0\">Enraging. Send the most elite squadron of the legion after it.</a></p>",
		'passages': {
		},
	},
	'DogRich': {
		'text': "<p>It is so.\nOur stewards to not have difficulty making space in the palace. So many empty rooms to spare. The dog wanders around the halls, soiling the marble floors and gnawing sacred paintings for sustenence. It is a sick creature, and will likely die within a few <a class=\"squiffy-link link-section\" data-section=\"Dec8\" role=\"link\" tabindex=\"0\">days</a>.</p>",
		'passages': {
		},
	},
	'DogDead': {
		'text': "<p>It is so.\nFifteen soldiers of the royal special military detach from their defence of the city&#39;s slim remaining fragments of common decency and begin hunting. \nbut the animal was never properly identified, and they lose the trail quickly. But they know not to disappoint their king, and the dog must be killed.\nThe only way to be certain, they decide, is to execute every dog in the city.</p>\n<p>There <a class=\"squiffy-link link-section\" data-section=\"Dec8\" role=\"link\" tabindex=\"0\">aren&#39;t many left</a> anyway.</p>",
		'passages': {
		},
	},
	'Dec8': {
		'text': "<p>Some now pray to the famine as a god. Ragged churches of bone and spiderweb emerge in deserted districts, like slivers of teeth sprouting from septic gums. In fairness, the influence of the famine is much more visible and responsive than the gods of the state, who seem to have presently deserted us. Yes, the voice of the famine can be heard clearest of all, even if the only language it speaks is <a class=\"squiffy-link link-section\" data-section=\"Dec9\" role=\"link\" tabindex=\"0\">death</a>.</p>",
		'passages': {
		},
	},
	'Dec9': {
		'clear': true,
		'text': "<p>One night, you <a class=\"squiffy-link link-section\" data-section=\"dream\" role=\"link\" tabindex=\"0\">dream</a>.</p>",
		'passages': {
		},
	},
	'dream': {
		'text': "<p>You are standing in the middle of a grove. You remember it from the palace gardens. Pristine as ever. {if seen Uneven:The grass is perfectly even.}\n{if seen Stream:A stream cuts through it, fine as crystal.}\n{if seen Ugly:There was an uglier garden here before, long since excised from the world and painted over.}</p>\n<p>you look over your shoulder, and notice that the gardens now stretch across the entire world. You wonder why you cannot see your palace, only to realise, laughing, that it has been woven into the constellations of the night sky. Quite a clever trick of archecture, that. Very well. The stars have <a class=\"squiffy-link link-section\" data-section=\"earnt the honour\" role=\"link\" tabindex=\"0\">earnt the honour</a>.</p>",
		'passages': {
		},
	},
	'earnt the honour': {
		'text': "<p>Sitting on a marble bench is a woman with long, black hair. She turns to you and smiles. Her eyes are gentle hearths of joy, and her dress is made of polished moonbeams. She is the most beautiful woman you have ever seen. No... no mere woman could claim such beauty. She must be your kingdom itself - an avatar, infinite glory compressed and purified into a singular perfect being.</p>\n<p>&#39;Come&#39;, she says, and extends her arm, inviting, &#39;<a class=\"squiffy-link link-section\" data-section=\"Moon\" role=\"link\" tabindex=\"0\">look at the moon with me.</a>&#39;</p>",
		'passages': {
		},
	},
	'Moon': {
		'text': "<p>But there is no moon.</p>\n<p>There is only a great, beady eye, the eye that hurts to see, pulsing with an angry, sinful energy. The sun lets loose a thousand rays of light, invisible spears, that corrupt and burn all that they touch.\nYou <a class=\"squiffy-link link-section\" data-section=\"look down\" role=\"link\" tabindex=\"0\">look down</a>.</p>",
		'passages': {
		},
	},
	'look down': {
		'text': "<p>The garden is aflame. You carry the woman in your arms, her left arm trailing in the embers, fiery burns spreading across her face. She tries to speak. Her lips are smeared with black poison. You <a class=\"squiffy-link link-section\" data-section=\"lean in close\" role=\"link\" tabindex=\"0\">lean in close</a>...</p>",
		'passages': {
		},
	},
	'lean in close': {
		'clear': true,
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"D1\" role=\"link\" tabindex=\"0\">&#39;Shield my face.&#39;</a></p>",
		'passages': {
		},
	},
	'D1': {
		'clear': true,
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"D2\" role=\"link\" tabindex=\"0\">&#39;Hide me from his sight.&#39;</a></p>",
		'passages': {
		},
	},
	'D2': {
		'clear': true,
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"D3\" role=\"link\" tabindex=\"0\">&#39;bring me below the ground.&#39;</a></p>",
		'passages': {
		},
	},
	'D3': {
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"Dec10\" role=\"link\" tabindex=\"0\">There is a chasm ahead, slanting into darkness. You wake up before you reach it.</a></p>",
		'passages': {
		},
	},
	'Dec10': {
		'clear': true,
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"Dec11\" role=\"link\" tabindex=\"0\">Morning.</a></p>",
		'passages': {
		},
	},
	'Dec11': {
		'clear': true,
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"Dec12\" role=\"link\" tabindex=\"0\">But different.</a></p>",
		'passages': {
		},
	},
	'Dec12': {
		'text': "<p>This time, standing in the light, you can feel his jealously. His anger. He poisoned the grain with sickly rays and caused this famine. The audacity - to try and steal your kingdom, to take that which to him does not belong. You should have known from the start. To shine so brightly as to force you to divert your gaze elsewhere. Nothing else in the world does that. It was always <a class=\"squiffy-link link-section\" data-section=\"Dec13\" role=\"link\" tabindex=\"0\">intolerable behaviour</a>.</p>",
		'passages': {
		},
	},
	'Dec13': {
		'text': "<p>The Sun has committed all these crimes against you. You must <a class=\"squiffy-link link-section\" data-section=\"Dec14\" role=\"link\" tabindex=\"0\">retaliate</a>.</p>",
		'passages': {
		},
	},
	'Dec14': {
		'text': "<p>The least soiled room of the palace is selected for your usage. Maps are laid out before you.\nThe generals and managers of state are assembled, or at least the few who are not presently engaged in wrestling their respective crises. They wait for your orders with apprehension and hope.</p>\n<p><a class=\"squiffy-link link-section\" data-section=\"SunTrick\" role=\"link\" tabindex=\"0\">The sun has limited stamina. He emerges in the morning, and retreats at night. We should adjust the protocols of sleep. If the nation wakes at dusk, works through the night, and retires before dawn, the sun will rule over only a deserted daytime. We will thus be immune to its light-rays, through which it dispenses foul magicks and energies.</a></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"SunWar\" role=\"link\" tabindex=\"0\">Modern science suggests that the sun rests four thousand feet above the surface, far beyond the grasp of even our tallest towers. Thus, we will test the range of our artillery, and drive him from the sky.</a></p>",
		'passages': {
		},
	},
	'SunTrick': {
		'text': "<p>You give the order for all men and women of the kingdom to cease work and only resume it after the sun has left the sky. Your advisors say that your orders are no longer heard much further beyond the borders of the palace. But if the people of the countryside not wish to listen, they can suffer under the sun&#39;s rays a little longer. You&#39;ll <a class=\"squiffy-link link-section\" data-section=\"Suntrick2\" role=\"link\" tabindex=\"0\">deal with them later.</a></p>",
		'passages': {
		},
	},
	'Suntrick2': {
		'text': "<p>It works smoothly at first. All business is conducted under the gentle radiance of the moon, and the sun&#39;s raging light cannot reach those who are asleep.</p>\n<p>But one night, you awake to discover the sun in the sky again, flooding the air with sickly light. It has switched places with the moon, or devoured it. You demand that the days be inverted again <a class=\"squiffy-link link-section\" data-section=\"but\" role=\"link\" tabindex=\"0\">but</a></p>",
		'passages': {
		},
	},
	'but': {
		'clear': true,
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"he\" role=\"link\" tabindex=\"0\">he</a></p>",
		'passages': {
		},
	},
	'he': {
		'clear': true,
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"keeps\" role=\"link\" tabindex=\"0\">keeps</a></p>",
		'passages': {
		},
	},
	'keeps': {
		'clear': true,
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"switching\" role=\"link\" tabindex=\"0\">switching -</a></p>",
		'passages': {
		},
	},
	'switching': {
		'clear': true,
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"- chasing\" role=\"link\" tabindex=\"0\">- chasing</a></p>",
		'passages': {
		},
	},
	'- chasing': {
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"DaysNights\" role=\"link\" tabindex=\"0\">chasing you forever!</a></p>",
		'passages': {
		},
	},
	'DaysNights': {
		'text': "<p>No matter when you order the people asleep, the sun is always waiting for you when you wake.</p>\n<p>And thus, the days become days again, the sun laughs, and your <a class=\"squiffy-link link-section\" data-section=\"D15\" role=\"link\" tabindex=\"0\">anger only grows</a>.</p>",
		'passages': {
		},
	},
	'SunWar': {
		'text': "<p>The engineers wheel their cannons up to the palace observatory. The roof of the orrery is demolished to afford a clearer line of sight.\nThey <a class=\"squiffy-link link-section\" data-section=\"fire\" role=\"link\" tabindex=\"0\">fire</a>.</p>",
		'passages': {
		},
	},
	'fire': {
		'clear': true,
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"TwoDays\" role=\"link\" tabindex=\"0\">They fire for two nights and two days.</a></p>",
		'passages': {
		},
	},
	'TwoDays': {
		'clear': true,
		'text': "<p>They fire for two nights and- a day! A day! They have failed. The sun remains in the sky. <a class=\"squiffy-link link-section\" data-section=\"D15\" role=\"link\" tabindex=\"0\">Mocking you</a>.</p>",
		'passages': {
		},
	},
	'D15': {
		'clear': true,
		'text': "<p>Morning. <a class=\"squiffy-link link-section\" data-section=\"D16\" role=\"link\" tabindex=\"0\">Endless morning</a>.</p>",
		'passages': {
		},
	},
	'D16': {
		'text': "<p>Hours pacing the throne room. No visitors are permitted. The drapes are drawn.\nBeyond them, the capital has fallen under silence, only interrupted on occasion by a distant rifle&#39;s gunpowder chord.\nEvery now and then, a gust of wind blows the curtains open, and an interloping sunbeam sneaks through and coils around the foot of your throne. Each time, you stomp it furiously until it retreats.\nAnd then - a knock at the door. An interloper of a <a class=\"squiffy-link link-section\" data-section=\"D17\" role=\"link\" tabindex=\"0\">different sort</a>.</p>",
		'passages': {
		},
	},
	'D17': {
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"D18\" role=\"link\" tabindex=\"0\">My king.</a></p>",
		'passages': {
		},
	},
	'D18': {
		'text': "<p>I implore you, my king. Starvation wracks the capital, and the rest of the kingdom fares no better. The armies have almost entirely dissolved, and the remnants prowl the wastes in ragged bands, making use of their grand and noble weapons primarily for the extortion of potatoes from refugees. The neighbouring empires have deserted us. Xanadu is dying, my king, spilling out of itself. The kingdom is doomed.</p>\n<p><a class=\"squiffy-link link-section\" data-section=\"D19\" role=\"link\" tabindex=\"0\">...</a></p>",
		'passages': {
		},
	},
	'D19': {
		'text': "<p>But there is still hope. The palace is currently protects some two hundred survivors. Most of them are palace staff, but a fair number are refugees, and two royal garrisons remain loyal and willing to fight.\nThey are lost, and hungry, and desperate. If they stay here, my king, they will all perish with the last of our food supply. But there is still hope! </p>\n<p>If you speak to them, your majesty, you could convince them to leave the capital. Make pilgrimage to the southern border, far beyond which lie patches of unclaimed land, fertile with life. Perhaps we would meet other survivors there! We can yet still save a piece of Xanadu, carry it with us on our backs, with the soldiers to protect us, and your leadership to guide our hearts.</p>\n<p>Your mobile palace could be separated and ready for transport within hours. It would provide adequate lodgings for you - we could leave at sundown, before another child need fall dead by plague or hunger.\nPlease, my king, I beseech you, end this futile obsession with the sun, the forces of nature you cannot control. Your people need you, more than they have ever needed anything else.</p>\n<p><a class=\"squiffy-link link-section\" data-section=\"D20\" role=\"link\" tabindex=\"0\">...</a></p>",
		'passages': {
		},
	},
	'D20': {
		'text': "<p>My king, do you hear me?</p>\n<p><a class=\"squiffy-link link-section\" data-section=\"D21\" role=\"link\" tabindex=\"0\">I see.</a></p>",
		'passages': {
		},
	},
	'D21': {
		'text': "<p>My king?</p>\n<p><a class=\"squiffy-link link-section\" data-section=\"D22\" role=\"link\" tabindex=\"0\">You&#39;re one of his.</a></p>",
		'passages': {
		},
	},
	'D22': {
		'text': "<p>Pardon me, my king, but what do-</p>\n<p><a class=\"squiffy-link link-section\" data-section=\"D24\" role=\"link\" tabindex=\"0\">Gaurds! This man is an agent of the Beady Eye!</a></p>",
		'passages': {
		},
	},
	'D24': {
		'text': "<p>What-</p>\n<p><a class=\"squiffy-link link-section\" data-section=\"D2Bajil\" role=\"link\" tabindex=\"0\">Drag him out before dawn and present him to his master, with his head on a pike and his limbs twisted into a holy symbol.</a></p>",
		'passages': {
		},
	},
	'D2Bajil': {
		'text': "<p>No, stop - let go of me! You fools, can&#39;t you see what&#39;s happening? What&#39;s happened to him? You&#39;re all dying with him!</p>\n<p><a class=\"squiffy-link link-section\" data-section=\"D25\" role=\"link\" tabindex=\"0\">And purge the rest of my advisors too, while you&#39;re at it. Just to be safe. Who knows how many other spies the sun has hidden amongst my consul? We must be wary.</a></p>",
		'passages': {
		},
	},
	'D25': {
		'clear': true,
		'text': "<p>You spend the next day crouched near a crayfish cage, salvaged from the mound of scuttled fishing boats that now clog the docks. The last remaining royal artisan has attached mirrors to the inner surface. </p>\n<p>You use it to catch sunbeams, whenever they infiltrate your throne room. Then you pull them out (they writhe like eels) and dissect them, working to understand their inner mechanisms and send a warning to their <a class=\"squiffy-link link-section\" data-section=\"D26\" role=\"link\" tabindex=\"0\">sly sky-father.</a></p>",
		'passages': {
		},
	},
	'D26': {
		'text': "<p>The sunbeams rapidly dissolve when exposed to the air, like the deep sea fish scholars once presented to die for your amusement.\nNo matter how many pieces of the sun you catch and cut open, they all collapse into themselves in much the same way as those abyss-borne creatures did, fading back into the world within moments. A pungent black fluid stains your fingers.</p>\n<p><a class=\"squiffy-link link-section\" data-section=\"D27\" role=\"link\" tabindex=\"0\">Oh, well. On to the executions.</a></p>",
		'passages': {
		},
	},
	'D27': {
		'clear': true,
		'text': "<p>The stastician is led up to the plinth, an outcropping that emerges from the palace walls only a little below the clouds. His legs shake when he sees the sword, but makes no attempt to run. After all, where would he <a class=\"squiffy-link link-section\" data-section=\"D28\" role=\"link\" tabindex=\"0\">go</a>?</p>",
		'passages': {
		},
	},
	'D28': {
		'text': "<p>The general attempts to rally a desperate sort of coup as the soldiers drag him out. But he has trained the men too well, instilled in them an unshakeable loyalty to the crown. He opened them up, carved out the innards and filled the space with clockwork, made of them machines that hear orders only from your mouth. <a class=\"squiffy-link link-section\" data-section=\"D29\" role=\"link\" tabindex=\"0\">And now they open him</a>.</p>",
		'passages': {
		},
	},
	'D29': {
		'text': "<p>The scholar of the university. The world loses a great mind today. Maybe the vultures will find some use of it, if they can peck through his skull. The rest of the body is discarded, a <a class=\"squiffy-link link-section\" data-section=\"D30\" role=\"link\" tabindex=\"0\">machine without ghosts</a>.</p>",
		'passages': {
		},
	},
	'D30': {
		'clear': true,
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"D31\" role=\"link\" tabindex=\"0\">...</a></p>",
		'passages': {
		},
	},
	'D31': {
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"D32\" role=\"link\" tabindex=\"0\">Look at them.</a></p>",
		'passages': {
		},
	},
	'D32': {
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"D33\" role=\"link\" tabindex=\"0\">The peasants.</a></p>",
		'passages': {
		},
	},
	'D33': {
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"D34\" role=\"link\" tabindex=\"0\">The starving, huddled, stinking masses!</a></p>",
		'passages': {
		},
	},
	'D34': {
		'text': "<p>It was them. Them, all along. Plotting against you. Greedy little dirt-fingers, hunched over in the grain-fields.</p>\n<p>How could they do this? How could they bring this famine onto us, destroy this noble kingdom? </p>\n<p>They listened to the cruel promises of the sun, threw their curtains wide, let him enter their houses freely.</p>\n<p>We build rooves to keep the sun out. Yes, our ancestors knew that very well. <a class=\"squiffy-link link-section\" data-section=\"D35\" role=\"link\" tabindex=\"0\">But NOW-</a></p>",
		'passages': {
		},
	},
	'D35': {
		'clear': true,
		'text': "<p>NOW, these people have seen the famine - this mild shortage of grain - and they&#39;d throw away ten thousand years (a Hundred HUNDRED Years!) for the sun&#39;s cruel promises of a <a class=\"squiffy-link link-section\" data-section=\"D36\" role=\"link\" tabindex=\"0\">summer-warm kingdom</a>.</p>",
		'passages': {
		},
	},
	'D36': {
		'text': "<p>There&#39;s a piece of sunlight in each of them, now, wriggling in their throats, shaping their thoughts and bleaching their bones from the inside out.\nLook at them go. Packing up their things and pushing out into the empty city. Abandoning the palace for a sea of death and tumbled marble.\nYou watch them leave, your gaze without mercy. then return to your <a class=\"squiffy-link link-section\" data-section=\"throne room\" role=\"link\" tabindex=\"0\">throne room</a>.</p>",
		'passages': {
		},
	},
	'throne room': {
		'clear': true,
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"Days.\" role=\"link\" tabindex=\"0\">Days.</a></p>",
		'passages': {
		},
	},
	'Days.': {
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"Nights.\" role=\"link\" tabindex=\"0\">Nights.</a></p>",
		'passages': {
		},
	},
	'Nights.': {
		'text': "<p>It all starts to recede, now that the racket has died down. The <a class=\"squiffy-link link-section\" data-section=\"People\" role=\"link\" tabindex=\"0\">sound of people...</a></p>",
		'passages': {
		},
	},
	'People': {
		'text': "<p>It&#39;s become <a class=\"squiffy-link link-section\" data-section=\"very quiet\" role=\"link\" tabindex=\"0\">very quiet</a> all of a sudden.</p>",
		'passages': {
		},
	},
	'very quiet': {
		'text': "<p>You sit in your throne, looking out at the capital. The world is warm. \nWhen you sleep, you bend forward in the chair like an old elm. They left a pile of food in the corner, but you do not move for fear of tearing free from your roots.</p>\n<p>Fingernails move back and forth across the armrest. The gold refuses to bear grooves. Oh, to be an <a class=\"squiffy-link link-section\" data-section=\"Thing\" role=\"link\" tabindex=\"0\">immmortal thing...</a></p>",
		'passages': {
		},
	},
	'Thing': {
		'text': "<p>Outside, the buildings remain standing, the ancient fortresses and the halls of knowledge. But the sun is coming down, and it brings with it the vast blanket of night, draping it over the capital.</p>\n<p>In times past, you could have looked into the dark and seen the lanterns in the windows, the candlelight of church vigils, the glow of alchemic phosphors in the houses of science.\nBut there are no lights anymore, and everything has gone quiet. The night closes over everything and at last crawls into your throne room, and there is no light to keep it away. It climbs over your throne, and takes the whole kingdom.\nYou know that by the time morning comes, there will be absolutely <a class=\"squiffy-link link-section\" data-section=\"nothing left.\" role=\"link\" tabindex=\"0\">nothing left.</a></p>",
		'passages': {
		},
	},
	'nothing left.': {
		'text': "<p>Do you have anything you&#39;d <a class=\"squiffy-link link-section\" data-section=\"like to say\" role=\"link\" tabindex=\"0\">like to say</a>?</p>",
		'passages': {
		},
	},
	'like to say': {
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"End\" role=\"link\" tabindex=\"0\">It is clear now that all empires are built on sand; all great works, drawn on dust.</a></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"End\" role=\"link\" tabindex=\"0\">Justice, order, truth and history. These things are not real, only existing in the minds of countless individuals, dreaming the same dream in a connected pattern. Without this web, there is nothing else of value.</a></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"End\" role=\"link\" tabindex=\"0\">We must gaurd our dreams closest of all, lest they be swallowed up by the dreams of calloused futures.</a></p>",
		'passages': {
		},
	},
	'End': {
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"End2\" role=\"link\" tabindex=\"0\">It is so, my king, it is so.</a></p>",
		'passages': {
		},
	},
	'End2': {
		'text': "<p><a class=\"squiffy-link link-section\" data-section=\"End3\" role=\"link\" tabindex=\"0\">-</a></p>",
		'passages': {
		},
	},
	'End3': {
		'text': "<p>KING OF XANADU</p>\n<p>Brought to you by</p>\n<p>MACHINES UNDERNEATH.</p>\n<p>Thank you for playing.</p>",
		'passages': {
		},
	},
}
})();